changeset 647:8d7c75cc01e3

Adapt test for getTableTypes(). Filter out UNLOGGED TABLE value for stable output on all future and past MonetDB versions.
author Martin van Dinther <martin.van.dinther@monetdbsolutions.com>
date Thu, 14 Apr 2022 19:46:42 +0200 (2022-04-14)
parents 1db097f11e28
children 03e0f577db00
files tests/JDBC_API_Tester.java
diffstat 1 files changed, 3 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/tests/JDBC_API_Tester.java
+++ b/tests/JDBC_API_Tester.java
@@ -4005,8 +4005,9 @@ final public class JDBC_API_Tester {
 				sb.append("List TableTypes:\n");
 				while (rs2.next()) {
 					String tt = rs2.getString(1);
-					// post Oct2020 releases the STREAM TABLE type is removed, so filter it out for a stable output
-					if (!"STREAM TABLE".equals(tt))
+					// the STREAM TABLE type is REMOVED in post Oct2020 releases, so filter it out for a stable output on all releases
+					// the UNLOGGED TABLE type is ADDED in post Jan2022 releases, so filter it out for a stable output on all releases
+					if (! ("STREAM TABLE".equals(tt) || "UNLOGGED TABLE".equals(tt)) )
 						sb.append(tt).append("\n");
 				}
 				rs2.close();